netapp_ontap.models.shelf_drawers API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.shelf_drawers`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ShelfDrawersSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ShelfDrawers object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `closed: bool GET POST PATCH`

    The closed field of the shelf_drawers.

  `disk_count: Size GET POST PATCH`

    The disk_count field of the shelf_drawers.

    Example: 12

  `error: str GET POST PATCH`

    The error field of the shelf_drawers.

  `id: Size GET POST PATCH`

    The id field of the shelf_drawers.

  `part_number: str GET POST PATCH`

    The part_number field of the shelf_drawers.

    Example: 111-03071

  `serial_number: str GET POST PATCH`

    The serial_number field of the shelf_drawers.

    Example: 2.1604008263E10

  `state: str GET POST PATCH`

    The state field of the shelf_drawers.

    Valid choices:

    - ok
    - error